chop.data
=========

.. automodule:: chop.data

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      CIFAR10
      Dataset
      ImageNet
      NormalizingModel
   
   

   
   
   



